==> apache-ant-1.8.1-src.tar.bz2: apache-ant-1.8.1/src/tests/junit/org/apache/tools/ant/taskdefs/TestProcess.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.tools.ant.taskdefs;

/**
 * Interactive Testcase for Processdestroyer.
 *
 */
public class TestProcess
    implements Runnable
{
    private boolean run = true;
    private boolean done = false;

    public void shutdown()
    {
        if (!done)
        {
            System.out.println("shutting down TestProcess");
            run = false;

            synchronized(this)
            {
                while (!done)
                {
                    try { wait(); } catch (InterruptedException ie) {}
                }
            }

            System.out.println("TestProcess shut down");
        }
    }

    public void run()
    {
        for (int i = 0; i < 5 && run; i++)
        {
            System.out.println(Thread.currentThread().getName());

            try { Thread.sleep(2000); } catch (InterruptedException ie) {}
        }

        synchronized(this)
        {
            done = true;
            notifyAll();
        }
    }

    public Thread getShutdownHook()
    {
        return new TestProcessShutdownHook();
    }

    private class TestProcessShutdownHook
        extends Thread
    {
        public void run()
        {
            shutdown();
        }
    }

    public static void main(String[] args)
    {
        TestProcess tp = new TestProcess();
        new Thread(tp, "TestProcess thread").start();
        Runtime.getRuntime().addShutdownHook(tp.getShutdownHook());
    }
}

==> apache-ant-1.9.11-src.tar.bz2: apache-ant-1.9.11/src/tests/junit/org/apache/tools/ant/taskdefs/TestProcess.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.tools.ant.taskdefs;

import org.junit.internal.AssumptionViolatedException;

/**
 * Interactive Testcase for Processdestroyer.
 *
 */
public class TestProcess implements Runnable {
    private boolean run = true;
    private boolean done = false;

    public void shutdown() {
        if (!done) {
            System.out.println("shutting down TestProcess");
            run = false;

            synchronized (this) {
                while (!done) {
                    try {
                        wait();
                    } catch (InterruptedException ie) {
                        throw new AssumptionViolatedException("Thread interrupted", ie);
                    }
                }
            }

            System.out.println("TestProcess shut down");
        }
    }

    public void run() {
        for (int i = 0; i < 5 && run; i++) {
            System.out.println(Thread.currentThread().getName());

            try {
                Thread.sleep(2000);
            } catch (InterruptedException ie) {
                throw new AssumptionViolatedException("Thread interrupted", ie);
            }
        }

        synchronized (this) {
            done = true;
            notifyAll();
        }
    }

    public Thread getShutdownHook() {
        return new TestProcessShutdownHook();
    }

    private class TestProcessShutdownHook extends Thread {
        public void run() {
            shutdown();
        }
    }

    public static void main(String[] args) {
        TestProcess tp = new TestProcess();
        new Thread(tp, "TestProcess thread").start();
        Runtime.getRuntime().addShutdownHook(tp.getShutdownHook());
    }
}
